@@ -112,7 +112,7 @@ zenity_msg (ZenityData *data, ZenityMsgData *msg_data)
     gtk_window_set_default_size (GTK_WINDOW (dialog), data->width, data->height);
         
   if (msg_data->dialog_text)
-    gtk_label_set_text (GTK_LABEL (text), msg_data->dialog_text);
+    gtk_label_set_markup (GTK_LABEL (text), msg_data->dialog_text);
 
   zenity_util_show_dialog (dialog);
   gtk_main ();
@@ -126,16 +126,15 @@ zenity_msg_dialog_response (GtkWidget *widget, int response, gpointer data)
   switch (response) {
     case GTK_RESPONSE_OK:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
-      gtk_main_quit ();
       break;
 
     case GTK_RESPONSE_CANCEL:
       zen_data->exit_code = zenity_util_return_exit_code (ZENITY_CANCEL);
-      gtk_main_quit ();
       break;
 
     default:
-      zen_data->exit_code = 1;
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_ESC);
       break;
   }
+  gtk_main_quit ();
 }
